from django.db import models
from datetime import datetime

class PublishedManager(models.Manager):

    def get_query_set(self):
        return super(PublishedManager, self).get_query_set().filter(published=True)

class PublishedPostManager(models.Manager):
    def get_query_set(self):
        now = datetime.now()
        return super(PublishedPostManager, self).get_query_set().filter(publish_date__lte=now, is_active=True)




import logging
from django.conf import settings
from django.core.urlresolvers import reverse
from django.utils.functional import lazy
from django.conf.urls.defaults import *
from django.template import loader, RequestContext
from django.views.generic import DetailView, ListView 
from django.views.generic.edit import CreateView, UpdateView, DeleteView

from multiblogs.models import Blog, Post
from multiblogs.forms import PostForm

WITHOUT_SETS= getattr(settings, 'MULTIBLOGS_WITHOUT_SETS', False)

if not WITHOUT_SETS:
    from multiblogs.models import BlogSet
    class BlogSetView(DetailView):
        model=BlogSet
        queryset=BlogSet.published_objects.all()
        template_name_field = 'template_name'
    

class BlogDetailView(DetailView):
    model=Blog
    template_name_field = 'template_name'

    def get_queryset(self):
        if not WITHOUT_SETS:
            queryset=Blog.published_objects.filter(blog_set__slug=self.kwargs['blog_set_slug'])
        else:
            queryset=Blog.published_objects.all()
        return queryset

class PostYearListView(ListView):
    model=Post
    template_name_field = 'blog__template_name'

    def get_queryset(self):
        if not WITHOUT_SETS:
            queryset=Post.published_objects.all().filter(blog__blog_set__slug=self.kwargs['blog_set_slug'], blog__slug=self.kwargs['blog_slug'], publish_date__year=self.kwargs['year'])
        else:
            queryset=Post.published_objects.all().filter(blog__slug=self.kwargs['slug'], publish_date__year=self.kwargs['year'])
        return queryset

class PostDetailView(DetailView):
    model=Post
    template_name_field = 'blog__template_name'

    def get_queryset(self):
        if not WITHOUT_SETS:
            queryset=Post.published_objects.all().filter(blog__blog_set__slug=self.kwargs['blog_set_slug'], blog__slug=self.kwargs['blog_slug'], publish_date__year=self.kwargs['year'])
        else:
            queryset=Post.published_objects.all().filter(blog__slug=self.kwargs['slug'], publish_date__year=self.kwargs['year'])
        return queryset

class PostCreateView(CreateView):
    form_class=PostForm
    template_name='multiblogs/post_create.html'

    def get_context_data(self, **kwargs):
        context = super(PostCreateView, self).get_context_data(**kwargs)
        context['blog'] = Blog.published_objects.get(slug=self.kwargs['slug'])
        return context

class PostUpdateView(UpdateView):
    form_class=PostForm
    template_name='multiblogs/post_update.html'
    queryset=Post.objects.all()

    def get_context_data(self, **kwargs):
        context = super(PostUpdateView, self).get_context_data(**kwargs)
        context['blog'] = Blog.published_objects.get(slug=self.kwargs['blog_slug'])
        return context

class PostDeleteView(DeleteView):
    model=Post
    template_name='multiblogs/post_delete.html'
    success_url='/blogs/' 




import logging
from django.forms import ModelForm
from multiblogs.models import Post, Blog

class PostForm(ModelForm):
    class Meta:
        model = Post
        exclude = ('sites', 'keywords', 'slug', 'description', 'rendered_description', 'is_active', 'login_required', 'rendered_content', 'expiration_date', 'auto_tag', 'publish_date', 'followup_for', 'related_posts')

'''
    def save(self, *args, **kwargs):
        try:
            self.author_id = self.user.pk
            self.blog_id = Blog.objects.get(slug=kwargs['request'].path.split('/')[2]).pk
        except:
            pass
        super(PostForm, self).save(*args, **kwargs)
        '''



import logging
from django.conf import settings
from django.contrib import admin
from django.contrib.auth.models import User
from django.contrib.contenttypes import generic
from articles.models import ArticleStatus
from taggit.models import Tag
from django.utils.translation import ugettext_lazy as _

WITHOUT_SETS= getattr(settings, 'MULTIBLOGS_WITHOUT_SETS', False)
if not WITHOUT_SETS: 
    from multiblogs.models import BlogSet
    admin.site.register(BlogSet)

from multiblogs.models import Blog, Post, Attachment

class AttachmentInline(admin.TabularInline):
    model = Attachment
    extra = 5
    max_num = 15

class PostAdmin(admin.ModelAdmin):
    list_display = ('title', 'blog', 'status', 'author', 'publish_date',
                    'expiration_date', 'is_active')
    list_filter = ('author', 'status', 'is_active', 'publish_date',
                   'expiration_date', 'sites')
    list_per_page = 25
    search_fields = ('title', 'keywords', 'description', 'content')
    date_hierarchy = 'publish_date'
    inlines = [
        AttachmentInline,
    ]

    fieldsets = (
        (None, {'fields': ('title', 'blog', 'author', 'content', 'tags', 'auto_tag', 'markup', 'status')}),
        ('Metadata', {
            'fields': ('keywords', 'description',),
            'classes': ('collapse',)
        }),
        ('Relationships', {
            'fields': ('followup_for', 'related_posts'),
            'classes': ('collapse',)
        }),
        ('Scheduling', {'fields': ('publish_date', 'expiration_date')}),
        ('Advanced', {
            'fields': ('slug', 'is_active', 'login_required', 'sites'),
            'classes': ('collapse',)
        }),
    )

    filter_horizontal = ('followup_for', 'related_posts')
    prepopulated_fields = {'slug': ('title',)}

    def mark_active(self, request, queryset):
        queryset.update(is_active=True)
    mark_active.short_description = _('Mark select posts as active')

    def mark_inactive(self, request, queryset):
        queryset.update(is_active=False)
    mark_inactive.short_description = _('Mark select posts as inactive')

    def get_actions(self, request):
        actions = super(PostAdmin, self).get_actions(request)

        def dynamic_status(name, status):
            def status_func(self, request, queryset):
                queryset.update(status=status)

            status_func.__name__ = name
            status_func.short_description = _('Set status of selected to "%s"' % status)
            return status_func

        for status in ArticleStatus.objects.all():
            name = 'mark_status_%i' % status.id
            actions[name] = (dynamic_status(name, status), name, _('Set status of selected to "%s"' % status))

        def dynamic_tag(name, tag):
            def status_func(self, request, queryset):
                for article in queryset.iterator():
                    log.debug('Dynamic tagging: applying Tag "%s" to Article "%s"' % (tag, article))
                    article.tags.add(tag)
                    article.save()

            status_func.__name__ = name
            status_func.short_description = _('Apply tag "%s" to selected articles' % tag)
            return status_func

        for tag in Tag.objects.all():
            name = 'apply_tag_%s' % tag.pk
            actions[name] = (dynamic_tag(name, tag), name, _('Apply Tag: %s' % (tag.slug,)))

        return actions

    actions = [mark_active, mark_inactive]

    def save_model(self, request, obj, form, change):
        """Set the article's author based on the logged in user and make sure at least one site is selected"""

        try:
            author = obj.author
        except User.DoesNotExist:
            obj.author = request.user

        obj.save()

        # this requires an Article object already
        obj.do_auto_tag('default')
        form.cleaned_data['tags'] += list(obj.tags.all())

    def queryset(self, request):
        """Limit the list of articles to article posted by this user unless they're a superuser"""

        if request.user.is_superuser:
            return self.model._default_manager.all()
        else:
            return self.model._default_manager.filter(author=request.user)

admin.site.register(Blog)
admin.site.register(Post, PostAdmin)



import logging
import mimetypes
import re

from datetime import datetime
from django.db import models
from django.conf import settings
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _
from django.contrib.sites.models import Site

from taggit.managers import TaggableManager
from taggit.models import Tag
from articles.models import ArticleStatus
from articles.decorators import logtime, once_per_instance
from markup_mixin.models import MarkupMixin
from django_extensions.db.models import TitleSlugDescriptionModel
from django_extensions.db.fields import AutoSlugField
from django.template.defaultfilters import slugify, striptags

from multiblogs.managers import PublishedManager, PublishedPostManager

WORD_LIMIT=200
MARKUP_HTML = 'h'
MARKUP_MARKDOWN = 'm'
MARKUP_REST = 'r'
MARKUP_TEXTILE = 't'
MARKUP_OPTIONS = getattr(settings, 'MULTIBLOG_MARKUP_OPTIONS', (
        (MARKUP_HTML, _('HTML/Plain Text')),
        (MARKUP_MARKDOWN, _('Markdown')),
        (MARKUP_REST, _('ReStructured Text')),
        (MARKUP_TEXTILE, _('Textile'))
    ))
MARKUP_DEFAULT = getattr(settings, 'MULTIBLOG_MARKUP_DEFAULT', MARKUP_HTML)

log = logging.getLogger('multiblogs.models')

# Of course, blog sets are one of our key features. But what the hell,
# let's let you turn them off if you want to. Just set MULTIBLOGS_WITHOUT_SETS
# to True in your settings.py file.
WITHOUT_SETS= getattr(settings, 'MULTIBLOGS_WITHOUT_SETS', False)
AUTO_TAG = getattr(settings, 'MULTIBLOGS_AUTO_TAG', True)

if not WITHOUT_SETS:
    class BlogSet(MarkupMixin, TitleSlugDescriptionModel):
        published = models.BooleanField(_('Published'), default=True)
        rendered_description=models.TextField(_('Rendered description'), blank=True, null=True)
        logo = models.ImageField(_('Logo'), blank=True, null=True, upload_to='multiblogs/blog_sets/logos/')
        template_name = models.CharField(_('template name'), max_length=255, blank=True, help_text=_("Example: 'multiblogs/blog_sets/art-class.html'. If this isn't provided, the system will use 'multiblogs/blog_set_detail.html'."))

        objects = models.Manager()
        published_objects = PublishedManager()
    
        def get_blogs(self, live=True, order_by='title'):
            '''
            Get all the blogs in this set that are live and orderd by their titles.
    
            Parameters include whether blogs should be live, and an ordering expression.
    
            Order can be any sortable field on the Blog model.
            '''
            return Blog.objects.filter(blog_set__slug=self.slug, published=live).order_by(order_by)
    
        def __unicode__(self):
            return self.title
            
        class Meta:
            verbose_name=_('Blog set')
            verbose_name_plural=_('Blog sets')
    
        class MarkupOptions:
            source_field = 'description'
            rendered_field = 'rendered_description'

class Blog(MarkupMixin, TitleSlugDescriptionModel):
    if not WITHOUT_SETS:
        blog_set = models.ForeignKey(BlogSet, blank=True, null=True)
    authors = models.ManyToManyField(User, related_name="authors")
    contributors=models.ManyToManyField(User, related_name="contributors", blank=True, null=True)
    published = models.BooleanField(_('Published'), default=True)
    rendered_description=models.TextField(_('Rendered description'), blank=True, null=True)
    logo = models.ImageField(_('Logo'), blank=True, null=True, upload_to='multiblogs/blogs/logos/')
    at_most = models.IntegerField('Show at most', default=5, help_text='Number of posts to show for this blog.')
    date_format = models.CharField('date format', max_length=30, default='F j, Y', help_text='Date format for this blog.')
    time_format = models.CharField('time format', max_length=30, default='g:i A', help_text='Time format for this blog.')
    template_name = models.CharField(_('template name'), max_length=255, blank=True, help_text=_("Example: 'multiblogs/blogs/whales-galore.html'. If this isn't provided, the system will use 'multiblogs/blog_detail.html'."))

    objects = models.Manager()
    published_objects = PublishedManager()

    def get_authors(self):
        '''
        Returns a string with each author's either full name or username, depending on what's available.
        '''
        authors = []
        for a in self.authors.all():
            if a.first_name or a.last_name:
                authors.append(a.first_name + " " + a.last_name)
            else:
                authors.append(a.username)
        
        # Cannot find user, return byline
        return ", ".join(authors)

    def get_posts(self, start=None, drafts=False, order_by='-publish_date', at_most=10):
        '''
        Get all the published posts in a blog.
        
        Parameters:
            start -- starting index for result set
            drafts -- True to return only drafts, False to return only published posts
            order_by -- expression specifying the order of the result set

        '''
        posts = Post.objects.filter(blog__slug=self.slug, publish_date__isnull=drafts)
        if start:
            posts = posts.filter(publish_date__gte=start)
        return posts.order_by(order_by)[:at_most]

    def get_post_count(self, drafts=False):
        '''
        Count all posts, published by default, but you can ask it to count all posts.
        '''
        return Post.objects.filter(blog__slug=self.slug, publish_date__isnull=drafts).count()

    def __unicode__(self):
        return self.title
        
    @models.permalink
    def get_absolute_url(self):
        if not WITHOUT_SETS:
            return ('mb-blog-detail', (self.blog_set.slug, self.slug))
        else:
            return ('mb-blog-detail', (self.slug))

    class Meta:
        verbose_name=_('Blog')
        verbose_name_plural=_('Blogs')

    class MarkupOptions:
        source_field = 'description'
        rendered_field = 'rendered_description'

class PostManager(models.Manager):

    def active(self):
        """
        Retrieves all active articles which have been published and have not
        yet expired.
        """
        now = datetime.now()
        return self.get_query_set().filter(
                Q(expiration_date__isnull=True) |
                Q(expiration_date__gte=now),
                publish_date__lte=now,
                is_active=True)

    def live(self, user=None):
        """Retrieves all live articles"""

        qs = self.active()

        if user is not None and user.is_superuser:
            # superusers get to see all articles
            return qs
        else:
            # only show live articles to regular users
            return qs.filter(status__is_live=True)

MARKUP_HELP = _("""Select the type of markup you are using in this post.
<ul>
<li><a href="http://daringfireball.net/projects/markdown/basics" target="_blank">Markdown Guide</a></li>
<li><a href="http://docutils.sourceforge.net/docs/user/rst/quickref.html" target="_blank">ReStructured Text Guide</a></li>
<li><a href="http://thresholdstate.com/articles/4312/the-textile-reference-manual" target="_blank">Textile Guide</a></li>
</ul>""")


class PostBase(models.Model):
    title = models.CharField(max_length=100)
    slug = models.SlugField(unique_for_year='publish_date')
    status = models.ForeignKey(ArticleStatus, default=ArticleStatus.objects.default)
    author = models.ForeignKey(User)
    sites = models.ManyToManyField(Site, blank=True)

    keywords = models.TextField(blank=True, help_text=_("If omitted, the keywords will be the same as the article tags."))
    description = models.TextField(blank=True, help_text=_("If omitted, the description will be determined by the first bit of the article's content."))

    markup = models.CharField(max_length=1, choices=MARKUP_OPTIONS, default=MARKUP_DEFAULT, help_text=MARKUP_HELP)
    content = models.TextField()
    rendered_content = models.TextField()

    publish_date = models.DateTimeField(default=datetime.now, help_text=_('The date and time this article shall appear online.'))
    expiration_date = models.DateTimeField(blank=True, null=True, help_text=_('Leave blank if the article does not expire.'))

    is_active = models.BooleanField(default=True, blank=True)
    login_required = models.BooleanField(blank=True, help_text=_('Enable this if users must login before they can read this article.'))

    objects = PostManager()

    def __init__(self, *args, **kwargs):
        """Makes sure that we have some rendered content to use"""

        super(PostBase, self).__init__(*args, **kwargs)

        self._next = None
        self._previous = None
        self._teaser = None

        if self.id:
            # mark the article as inactive if it's expired and still active
            if self.expiration_date and self.expiration_date <= datetime.now() and self.is_active:
                self.is_active = False
                self.save()

            if not self.rendered_content or not len(self.rendered_content.strip()):
                self.save()

    def __unicode__(self):
        return self.title

    def save(self, *args, **kwargs):
        """Renders the article using the appropriate markup language."""


        self.do_render_markup()
        self.do_meta_description()

        requires_save=False
        super(PostBase, self).save(*args, **kwargs)

        # do some things that require an ID first
        requires_save |= self.do_default_site(using)

        if requires_save:
            # bypass the other processing
            super(PostBase, self).save()

    def do_render_markup(self):
        """Turns any markup into HTML"""

        original = self.rendered_content
        if self.markup == MARKUP_MARKDOWN:
            self.rendered_content = markup.markdown(self.content)
        elif self.markup == MARKUP_REST:
            self.rendered_content = markup.restructuredtext(self.content)
        elif self.markup == MARKUP_TEXTILE:
            self.rendered_content = markup.textile(self.content)
        else:
            self.rendered_content = self.content

        return (self.rendered_content != original)


    def do_meta_description(self):
        """
        If meta description is empty, sets it to the article's teaser.

        Returns True if an additional save is required, False otherwise.
        """

        if len(self.description.strip()) == 0:
            self.description = self.teaser
            return True

        return False


    def do_default_site(self):
        """
        If no site was selected, selects the site used to create the article
        as the default site.

        Returns True if an additional save is required, False otherwise.
        """

        if not len(self.sites.all()):
            sites = Site.objects.all()
            if hasattr(sites, 'using'):
                sites = sites.using(using)
            self.sites.add(sites.get(pk=settings.SITE_ID))
            return True

        return False


    def _get_article_links(self):
        """
        Find all links in this article.  When a link is encountered in the
        article text, this will attempt to discover the title of the page it
        links to.  If there is a problem with the target page, or there is no
        title (ie it's an image or other binary file), the text of the link is
        used as the title.  Once a title is determined, it is cached for a week
        before it will be requested again.
        """

        links = []

        # find all links in the article
        log.debug('Locating links in article: %s' % (self,))
        for link in LINK_RE.finditer(self.rendered_content):
            url = link.group(1)
            log.debug('Do we have a title for "%s"?' % (url,))
            key = 'href_title_' + sha1(url).hexdigest()

            # look in the cache for the link target's title
            title = cache.get(key)
            if title is None:
                log.debug('Nope... Getting it and caching it.')
                title = link.group(2)

                if LOOKUP_LINK_TITLE:
                    try:
                        log.debug('Looking up title for URL: %s' % (url,))
                        # open the URL
                        c = urllib.urlopen(url)
                        html = c.read()
                        c.close()

                        # try to determine the title of the target
                        title_m = TITLE_RE.search(html)
                        if title_m:
                            title = title_m.group(1)
                            log.debug('Found title: %s' % (title,))
                    except:
                        # if anything goes wrong (ie IOError), use the link's text
                        log.warn('Failed to retrieve the title for "%s"; using link text "%s"' % (url, title))

                # cache the page title for a week
                log.debug('Using "%s" as title for "%s"' % (title, url))
                cache.set(key, title, 604800)

            # add it to the list of links and titles
            if url not in (l[0] for l in links):
                links.append((url, title))

        return tuple(links)
    links = property(_get_article_links)

    def _get_word_count(self):
        """Stupid word counter for an article."""

        return len(striptags(self.rendered_content).split(' '))
    word_count = property(_get_word_count)

    @models.permalink
    def get_absolute_url(self):
        return ('articles_display_article', (self.publish_date.year, self.slug))

    def _get_teaser(self):
        """
        Retrieve some part of the article or the article's description.
        """
        if not self._teaser:
            if len(self.description.strip()):
                text = self.description
            else:
                text = self.rendered_content

            words = text.split(' ')
            if len(words) > WORD_LIMIT:
                text = '%s...' % ' '.join(words[:WORD_LIMIT])
            self._teaser = text

        return self._teaser
    teaser = property(_get_teaser)


    class Meta:
        abstract=True

class Post(PostBase):
    blog = models.ForeignKey(Blog)
    tags = TaggableManager()
    auto_tag = models.BooleanField(default=AUTO_TAG, blank=True, help_text=_('Check this if you want to automatically assign any existing tags to this post based on its content.'))
    followup_for = models.ManyToManyField('self', symmetrical=False, blank=True, help_text=_('Select any other posts that this post follows up on.'), related_name='followups')
    related_posts = models.ManyToManyField('self', blank=True)

    objects = models.Manager()
    published_objects = PublishedPostManager()

    def get_attachments(self):
        return Attachment.objects.filter(post__slug=self.slug)

    def save(self, *args, **kwargs):
        self.do_unique_slug()

        requires_save=False
        super(Post, self).save()

        requires_save = self.do_auto_tag()
        requires_save |= self.do_tags_to_keywords()

        if requires_save:
            # bypass the other processing
            super(Post, self).save()

    @logtime
    @once_per_instance
    def do_auto_tag(self):
        """
        Performs the auto-tagging work if necessary.

        Returns True if an additional save is required, False otherwise.
        """

        if not self.auto_tag:
            log.debug('Post "%s" (ID: %s) is not marked for auto-tagging. Skipping.' % (self.title, self.pk))
            return False

        # don't clobber any existing tags!
        existing_ids = [t.id for t in self.tags.all()]
        log.debug('Post %s already has these tags: %s' % (self.pk, existing_ids))

        unused = Tag.objects.all()
        unused = unused.exclude(id__in=existing_ids)

        found = False
        to_search = (self.content, self.title, self.description, self.keywords)
        for tag in unused:
            regex = re.compile(r'\b%s\b' % tag.name, re.I)
            if any(regex.search(text) for text in to_search):
                log.debug('Applying Tag "%s" (%s) to Post %s' % (tag, tag.pk, self.pk))
                self.tags.add(tag)
                found = True

        return found

    def do_unique_slug(self):
        """
        Ensures that the slug is always unique for the year this article was
        posted
        """

        if not self.id:
            # make sure we have a slug first
            if not len(self.slug.strip()):
                self.slug = slugify(self.title)

            self.slug = self.get_unique_slug(self.slug)
            return True

        return False

    def get_unique_slug(self, slug):
        """Iterates until a unique slug is found"""

        # we need a publish date before we can do anything meaningful
        if type(self.publish_date) is not datetime:
            return slug

        orig_slug = slug
        year = self.publish_date.year
        counter = 1

        while True:
            not_unique = Post.objects.all()
            not_unique = not_unique.filter(publish_date__year=year, slug=slug)

            if len(not_unique) == 0:
                return slug

            slug = '%s-%s' % (orig_slug, counter)
            counter += 1


    def do_tags_to_keywords(self):
        """
        If meta keywords is empty, sets them using the article tags.

        Returns True if an additional save is required, False otherwise.
        """

        if len(self.keywords.strip()) == 0:
            self.keywords = ', '.join([t.name for t in self.tags.all()])
            return True

        return False

    @models.permalink
    def get_absolute_url(self):
        if not WITHOUT_SETS:
            return ('mb-post-detail', (self.blog.blog_set.slug, self.blog.slug, self.publish_date.year, self.slug))
        else:
            return ('mb-post-detail', (self.blog.slug, self.publish_date.year, self.slug))

class Attachment(models.Model):
    upload_to = lambda inst, fn: 'attach/%s/%s/%s' % (datetime.now().year, inst.post.slug, fn)

    post = models.ForeignKey(Post, related_name='attachments')
    attachment = models.FileField(upload_to=upload_to)
    caption = models.CharField(max_length=255, blank=True)

    class Meta:
        ordering = ('-post', 'id')

    def __unicode__(self):
        return u'%s: %s' % (self.post, self.caption)

    @property
    def filename(self):
        return self.attachment.name.split('/')[-1]

    @property
    def content_type_class(self):
        mt = mimetypes.guess_type(self.attachment.path)[0]
        log.info('Check content type %s', mt)
        if mt:
            content_type = mt.replace('/', '_')
        else:
            # assume everything else is text/plain
            content_type = 'text_plain'

        return content_type
        



from django.conf import settings
from django.conf.urls.defaults import *
from django.views.generic import DetailView, ListView

from multiblogs.models import Blog, Post
from multiblogs.forms import PostForm
from multiblogs.views import BlogDetailView, PostYearListView, PostDetailView, PostCreateView, PostUpdateView, PostDeleteView

WITHOUT_SETS= getattr(settings, 'MULTIBLOGS_WITHOUT_SETS', False)
if not WITHOUT_SETS: 
    from multiblogs.models import BlogSet
    from multiblogs.views import BlogSetView
    urlpatterns = patterns('',
        url(r'^$', view=ListView.as_view(model=BlogSet, queryset=BlogSet.published_objects.all()),name="mb-blog-set-list"),
        url(r'^(?P<slug>[-\w]+)/$', view=BlogSetView.as_view(),name="mb-blog-set-detail"),
    	url(r'^(?P<blog_set_slug>[-\w]+)/(?P<slug>[-\w]+)/$', view=BlogDetailView.as_view(), name='mb-blog-detail'),
    	url(r'^(?P<blog_set_slug>[-\w]+)/(?P<slug>[-\w]+)/post/$', view=PostCreateView.as_view(), name='mb-post-create'),
    	url(r'^(?P<blog_set_slug>[-\w]+)/(?P<slug>[-\w]+)/(?P<year>[\d]+)/$', view=PostYearListView.as_view(), name='mb-post-year-archive'),
    	url(r'^(?P<blog_set_slug>[-\w]+)/(?P<blog_slug>[-\w]+)/(?P<year>[\d]+)/(?P<slug>[-\w]+)/$', view=PostDetailView.as_view(), name='mb-post-detail'),
    	url(r'^(?P<blog_set_slug>[-\w]+)/(?P<blog_slug>[-\w]+)/(?P<year>[\d]+)/(?P<slug>[-\w]+)/edit/$', view=PostUpdateView.as_view(), name='mb-post-update'),
    	url(r'^(?P<blog_set_slug>[-\w]+)/(?P<blog_slug>[-\w]+)/(?P<year>[\d]+)/(?P<slug>[-\w]+)/delete/$', view=PostDeleteView.as_view(), name='mb-post-delete'),
    )

else:
    urlpatterns = patterns('',
    	url(r'^(?P<slug>[-\w]+)/$', view=BlogDetailView.as_view(), name='mb-blog-detail'),
    	url(r'^(?P<slug>[-\w]+)/post/$', view=PostCreateView.as_view(), name='mb-post-create'),
    	url(r'^(?P<slug>[-\w]+)/(?P<year>[\d]+)/$', view=PostYearListView.as_view(), name='mb-post-year-archive'),
    	url(r'^(?P<blog_slug>[-\w]+)/(?P<year>[\d]+)/(?P<slug>[-\w]+)/$', view=PostDetailView.as_view(), name='mb-post-detail'),
    )




from django import template
from django.core.cache import cache
from django.contrib.contenttypes.models import ContentType
from classroom.models import Staff, School

register = template.Library()

class GetStaffNode(template.Node):
    """
    Retrieves a list of active staff members
    """
    def __init__(self, varname):
        self.varname = varname

    def render(self, context):
        staff = Staff.active_objects.all()

        context[self.varname] = staff
        return ''

def get_active_staff(parser, token):
    """
    Retrieves a list of active staff members

    {% get_active_staff as staff %}
    """
    args = token.split_contents()
    argc = len(args)

    try:
        assert argc == 3 and args[1] == 'as' 
    except AssertionError:
        raise template.TemplateSyntaxError('get_active_staff syntax: {% get_active_staff as varname %}')

    count = varname = None
    if argc == 3: t, a, varname = args
    elif argc == 4: t, count, a, varname = args

    return GetStaffNode(varname=varname)

class GetPrincipalNode(template.Node):
    """
    Retrieves a list of active principals
    """
    def __init__(self, varname):
        self.varname = varname

    def render(self, context):
        school = School.objects.get(primary=True)

        context[self.varname] = school.principal
        return ''

def get_active_principal(parser, token):
    """
    Retrieves a list of active principals

    {% get_active_principal as principal %}
    """
    args = token.split_contents()
    argc = len(args)

    try:
        assert argc == 3 and args[1] == 'as' 
    except AssertionError:
        raise template.TemplateSyntaxError('get_active_principal syntax: {% get_active_principal as varname %}')

    count = varname = None
    if argc == 3: t, a, varname = args
    elif argc == 4: t, count, a, varname = args

    return GetPrincipalNode(varname=varname)

class GetSchoolNode(template.Node):
    """
    Retrieves the currently primary school
    """
    def __init__(self, varname):
        self.varname = varname

    def render(self, context):
        school = School.objects.get(primary=True)

        context[self.varname] = school
        return ''

def get_primary_school(parser, token):
    """
    Retrieves the currently primary school

    {% get_primary_school as school %}
    """
    args = token.split_contents()
    argc = len(args)

    try:
        assert argc == 3 and args[1] == 'as' 
    except AssertionError:
        raise template.TemplateSyntaxError('get_primary_school syntax: {% get_primary_school as varname %}')

    varname = None
    t, a, varname = args

    return GetSchoolNode(varname=varname)

register.tag(get_primary_school)
register.tag(get_active_staff)
register.tag(get_active_principal)



from setuptools import setup, find_packages

setup(
    name='django-multiblogs',
    version=__import__('multiblogs').__version__,
    license="BSD",

    install_requires = [],

    description='An application for managing multiple blogs, and even *gasp* blog "sets".',
    long_description=open('README').read(),

    author='Colin Powell',
    author_email='colin@onecardinal.com',

    url='http://github.com/powellc/django-multiblogs',
    download_url='http://github.com/powellc/django-multiblogs/downloads',

    include_package_data=True,

    packages=['multiblogs'],

    zip_safe=True,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ],
)
